# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/operation/operation_requests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi.operation import types_pb2 as t2iapi_dot_operation_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)t2iapi/operation/operation_requests.proto\x12\x10t2iapi.operation\x1a\x1ct2iapi/operation/types.proto\"b\n\x17SetOperatingModeRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x37\n\x0eoperating_mode\x18\x02 \x01(\x0e\x32\x1f.t2iapi.operation.OperatingModeB9\n$com.draeger.medical.t2iapi.operationB\x11OperationRequestsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.operation.operation_requests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.draeger.medical.t2iapi.operationB\021OperationRequests'
  _SETOPERATINGMODEREQUEST._serialized_start=93
  _SETOPERATINGMODEREQUEST._serialized_end=191
# @@protoc_insertion_point(module_scope)
