# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/basic_responses.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi import response_types_pb2 as t2iapi_dot_response__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ct2iapi/basic_responses.proto\x12\x06t2iapi\x1a\x1bt2iapi/response_types.proto\"/\n\rBasicResponse\x12\x1e\n\x06result\x18\x01 \x01(\x0e\x32\x0e.t2iapi.ResultB,\n\x1a\x63om.draeger.medical.t2iapiB\x0e\x42\x61sicResponsesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.basic_responses_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.draeger.medical.t2iapiB\016BasicResponses'
  _BASICRESPONSE._serialized_start=69
  _BASICRESPONSE._serialized_end=116
# @@protoc_insertion_point(module_scope)
