# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/alert/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18t2iapi/alert/types.proto\x12\x0ct2iapi.alert*\x92\x01\n\x13\x41lertSignalPresence\x12\x1c\n\x18\x41LERT_SIGNAL_PRESENCE_ON\x10\x00\x12\x1d\n\x19\x41LERT_SIGNAL_PRESENCE_OFF\x10\x01\x12\x1f\n\x1b\x41LERT_SIGNAL_PRESENCE_LATCH\x10\x02\x12\x1d\n\x19\x41LERT_SIGNAL_PRESENCE_ACK\x10\x03*\x87\x02\n\x1f\x41lertConditionEscalationProcess\x12\x37\n3ALERT_CONDITION_ESCALATION_PROCESS_START_ESCALATION\x10\x00\x12\x36\n2ALERT_CONDITION_ESCALATION_PROCESS_STOP_ESCALATION\x10\x01\x12\x39\n5ALERT_CONDITION_ESCALATION_PROCESS_START_DEESCALATION\x10\x02\x12\x38\n4ALERT_CONDITION_ESCALATION_PROCESS_STOP_DEESCALATION\x10\x03*y\n\x1c\x41larmSignalInactivationState\x12+\n\'ALARM_SIGNAL_INACTIVATION_STATE_ENABLED\x10\x00\x12,\n(ALARM_SIGNAL_INACTIVATION_STATE_DISABLED\x10\x01*_\n\x16\x41lertConditionPresence\x12!\n\x1d\x41LERT_CONDITION_PRESENCE_TRUE\x10\x00\x12\"\n\x1e\x41LERT_CONDITION_PRESENCE_FALSE\x10\x01\x42.\n com.draeger.medical.t2iapi.alertB\nAlertTypesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.alert.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n com.draeger.medical.t2iapi.alertB\nAlertTypes'
  _ALERTSIGNALPRESENCE._serialized_start=43
  _ALERTSIGNALPRESENCE._serialized_end=189
  _ALERTCONDITIONESCALATIONPROCESS._serialized_start=192
  _ALERTCONDITIONESCALATIONPROCESS._serialized_end=455
  _ALARMSIGNALINACTIVATIONSTATE._serialized_start=457
  _ALARMSIGNALINACTIVATIONSTATE._serialized_end=578
  _ALERTCONDITIONPRESENCE._serialized_start=580
  _ALERTCONDITIONPRESENCE._serialized_end=675
# @@protoc_insertion_point(module_scope)
