# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/operation/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ct2iapi/operation/types.proto\x12\x10t2iapi.operation*j\n\rOperatingMode\x12\x1b\n\x17OPERATING_MODE_DISABLED\x10\x00\x12\x1a\n\x16OPERATING_MODE_ENABLED\x10\x01\x12 \n\x1cOPERATING_MODE_NOT_AVAILABLE\x10\x02\x42\x36\n$com.draeger.medical.t2iapi.operationB\x0eOperationTypesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.operation.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.draeger.medical.t2iapi.operationB\016OperationTypes'
  _OPERATINGMODE._serialized_start=50
  _OPERATINGMODE._serialized_end=156
# @@protoc_insertion_point(module_scope)
