# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/activation_state/service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi.activation_state import activation_state_requests_pb2 as t2iapi_dot_activation__state_dot_activation__state__requests__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%t2iapi/activation_state/service.proto\x12\x17t2iapi.activation_state\x1a\x1ct2iapi/basic_responses.proto\x1a\x37t2iapi/activation_state/activation_state_requests.proto2\xd1\x02\n\x16\x41\x63tivationStateService\x12_\n\x12SetAlertActivation\x12\x32.t2iapi.activation_state.SetAlertActivationRequest\x1a\x15.t2iapi.BasicResponse\x12g\n\x16SetComponentActivation\x12\x36.t2iapi.activation_state.SetComponentActivationRequest\x1a\x15.t2iapi.BasicResponse\x12m\n\x19SetSystemSignalActivation\x12\x39.t2iapi.activation_state.SetSystemSignalActivationRequest\x1a\x15.t2iapi.BasicResponseBH\n+com.draeger.medical.t2iapi.activation_stateB\x19\x41\x63tivationStateApiServiceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.activation_state.service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+com.draeger.medical.t2iapi.activation_stateB\031ActivationStateApiService'
  _ACTIVATIONSTATESERVICE._serialized_start=154
  _ACTIVATIONSTATESERVICE._serialized_end=491
# @@protoc_insertion_point(module_scope)
