# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/alert/service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi import basic_requests_pb2 as t2iapi_dot_basic__requests__pb2
from t2iapi.alert import alert_requests_pb2 as t2iapi_dot_alert_dot_alert__requests__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1at2iapi/alert/service.proto\x12\x0ct2iapi.alert\x1a\x1ct2iapi/basic_responses.proto\x1a\x1bt2iapi/basic_requests.proto\x1a!t2iapi/alert/alert_requests.proto\x1a\x1bgoogle/protobuf/empty.proto2\xbe\x05\n\x0c\x41lertService\x12\x62\n\x19SetAlertConditionPresence\x12..t2iapi.alert.SetAlertConditionPresenceRequest\x1a\x15.t2iapi.BasicResponse\x12\\\n\x16SetAlertSignalPresence\x12+.t2iapi.alert.SetAlertSignalPresenceRequest\x1a\x15.t2iapi.BasicResponse\x12>\n\rSetAudioPause\x12\x16.google.protobuf.Empty\x1a\x15.t2iapi.BasicResponse\x12\x41\n\x10\x43\x61ncelAudioPause\x12\x16.google.protobuf.Empty\x1a\x15.t2iapi.BasicResponse\x12`\n\x18\x41lertConditionEscalation\x12-.t2iapi.alert.AlertConditionEscalationRequest\x1a\x15.t2iapi.BasicResponse\x12n\n\x1fSetAlarmSignalInactivationState\x12\x34.t2iapi.alert.SetAlarmSignalInactivationStateRequest\x1a\x15.t2iapi.BasicResponse\x12P\n\x1bSetAlertSystemNotFunctional\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12\x45\n\x10InitiateAlarmOff\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponseB3\n com.draeger.medical.t2iapi.alertB\x0f\x41lertApiServiceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.alert.service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n com.draeger.medical.t2iapi.alertB\017AlertApiService'
  _ALERTSERVICE._serialized_start=168
  _ALERTSERVICE._serialized_end=870
# @@protoc_insertion_point(module_scope)
