# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/alert/alert_requests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi.alert import types_pb2 as t2iapi_dot_alert_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!t2iapi/alert/alert_requests.proto\x12\x0ct2iapi.alert\x1a\x18t2iapi/alert/types.proto\"D\n SetAlertConditionPresenceRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x10\n\x08presence\x18\x02 \x01(\x08\"d\n\x1dSetAlertSignalPresenceRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x33\n\x08presence\x18\x02 \x01(\x0e\x32!.t2iapi.alert.AlertSignalPresence\"t\n&SetAlarmSignalInactivationStateRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12:\n\x06\x65nable\x18\x02 \x01(\x0e\x32*.t2iapi.alert.AlarmSignalInactivationState\"|\n\x1f\x41lertConditionEscalationRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12I\n\x12\x65scalation_process\x18\x02 \x01(\x0e\x32-.t2iapi.alert.AlertConditionEscalationProcessB1\n com.draeger.medical.t2iapi.alertB\rAlertRequestsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.alert.alert_requests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n com.draeger.medical.t2iapi.alertB\rAlertRequests'
  _SETALERTCONDITIONPRESENCEREQUEST._serialized_start=77
  _SETALERTCONDITIONPRESENCEREQUEST._serialized_end=145
  _SETALERTSIGNALPRESENCEREQUEST._serialized_start=147
  _SETALERTSIGNALPRESENCEREQUEST._serialized_end=247
  _SETALARMSIGNALINACTIVATIONSTATEREQUEST._serialized_start=249
  _SETALARMSIGNALINACTIVATIONSTATEREQUEST._serialized_end=365
  _ALERTCONDITIONESCALATIONREQUEST._serialized_start=367
  _ALERTCONDITIONESCALATIONREQUEST._serialized_end=491
# @@protoc_insertion_point(module_scope)
