# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/basic_requests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bt2iapi/basic_requests.proto\x12\x06t2iapi\"$\n\x12\x42\x61sicHandleRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\"0\n\x15RepeatedStringRequest\x12\x17\n\x0frepeated_string\x18\x01 \x03(\tB+\n\x1a\x63om.draeger.medical.t2iapiB\rBasicRequestsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.basic_requests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.draeger.medical.t2iapiB\rBasicRequests'
  _BASICHANDLEREQUEST._serialized_start=39
  _BASICHANDLEREQUEST._serialized_end=75
  _REPEATEDSTRINGREQUEST._serialized_start=77
  _REPEATEDSTRINGREQUEST._serialized_end=125
# @@protoc_insertion_point(module_scope)
